---
name: Feature request
about: Propose a new feature
title: ''
labels: ''
assignees: ''

---

Remember to motivate and summarize considering the community. Provide enough information to motivate such as:

**Why is this feature important?**
**What is the potential impact of this feature in the community?**
**Is your feature request related to a problem? Please describe.**
**Describe the solution you'd like and potential required effort**
**Describe alternatives you've considered and potential required effort**

**Additional context**
Add any other context or screenshots about the feature request here.

Note: contents adapted from the [VTK contribution guidelines](https://github.com/Kitware/VTK/blob/master/Documentation/dev/git/develop.md#create-a-merge-request)
